PySPED
======

PySPED is a library to implement all requirements of the public system of bookkeeping digital (SPED portuguese acronym) including:

- Invoice: Electronic invoice for products
- NFse: Electronic invoice for services
- ES: Electronic Cargo Bill of Lading
- EDF: Electronic Tax Bookkeeping
- ECF: Electronic Accounting Bookkeeping

Install
-------

sudo python setup.py install
